@@ -14,9 +14,12 @@ SIMPLE_LAZ_FILE_PATH = Path(__file__).parent / "data" / "simple.laz"
 EXTRA_BYTES_LAZ_FILE_PATH = Path(__file__).parent / "data" / "extra.laz"
 PLANE_LAZ_FILE_PATH = Path(__file__).parent / "data" / "plane.laz"
 AUTZEN_FILE_PATH = Path(__file__).parent / "data" / "autzen.las"
+AUTZEN_GEO_PROJ_FILE_PATH = Path(__file__).parent / "data" / "autzen_geo_proj.las"
 LAZ_1_4_WITH_EVLRS_FILE_PATH = Path(__file__).parent / "data" / "1_4_w_evlr.laz"
 
-UNREGISTERED_EXTRA_BYTES_LAS = Path(__file__).parent / "data" / "unregistered_extra_bytes.las"
+UNREGISTERED_EXTRA_BYTES_LAS = (
+    Path(__file__).parent / "data" / "unregistered_extra_bytes.las"
+)
 
 ALL_LAS_FILE_PATH = [
     SIMPLE_LAS_FILE_PATH,
@@ -71,6 +74,22 @@ SUPPORTED_EXTRA_BYTES_TYPE = (
 )
 
 
+class NonSeekableStream:
+    """
+    Fake non stream / file object which simulates a file object
+    on which we cannot seek
+    """
+
+    def __init__(self, inner):
+        self.inner = inner
+
+    def read(self, n):
+        return self.inner.read(n)
+
+    def seekable(self):
+        return False
+
+
 @pytest.fixture()
 def simple_las_path():
     return SIMPLE_LAS_FILE_PATH
